@@ -7,6 +7,7 @@ from fosslight_util.help import PrintHelpMsg
 _HELP_MESSAGE_REUSE = """
     Usage: fosslight_reuse [Mode] [option1] <arg1> [option2] <arg2>...
         ex) fosslight_reuse lint -p /home/test/ -f "notice/sample.py,src/init.py"
+            fosslight_reuse add -p /home/test/ -c "Copyright 2019-2021 LG Electronics Inc." -l "GPL-3.0-only"
 
     FOSSLight Reuse is a Tool to check REUSE compliance in source code.
 
@@ -14,13 +15,17 @@ _HELP_MESSAGE_REUSE = """
         Mode
             lint\t\t    Check REUSE compliance
             report\t\t    oss_pkg_info.yaml <-> FOSSLight-Report.xml
+            add\t\t\t    Add missing license and copyright
 
         Options:
             -h\t\t\t    Print help message
             -p <path>\t\t    Path to check
             -f <file1,file2,..>\t    List of files to check
             -o <file_name>\t    Output file name
-            -n\t\t\t    Don't exclude venv*, node_modules, and .*/ from the analysis """
+            -n\t\t\t    Don't exclude venv*, node_modules, and .*/ from the analysis
+        Options for only 'add' mode
+            -l <license>\t    License name(SPDX format) to add
+            -c <copyright>\t    Copyright to add(ex, Copyright 2015-2021 LGE Electronics Inc.)"""
 
 
 def print_help_msg(exitOpt=True):
